@@ -408,7 +408,7 @@ update_scope(void)
 static void
 sound_vertical_scaling(void)
 	{
-	oscope->vert_max = (gint) ((gfloat) oscope->vert_sensitivity * 32767);
+	oscope->vert_max = (gint) (oscope->vert_sensitivity * 32767.0);
 
 	gkrellm_set_krell_full_scale(sound->krell_left, oscope->vert_max, 1);
 	gkrellm_set_krell_full_scale(sound->krell_right, oscope->vert_max, 1);
@@ -435,7 +435,10 @@ update_slider_position(Krell *k, gint x_ev)
 	oscope->vert_sensitivity = (100.0 - (gfloat) x) / 100.0;
 	if (oscope->vert_sensitivity < 0.05)
 		oscope->vert_sensitivity = 0.05;
+	if (oscope->vert_sensitivity > 1.0)
+		oscope->vert_sensitivity = 1.0;
 	sound_vertical_scaling();
+	gkrellm_config_modified();
 	gkrellm_update_krell(chart->panel, k, (gulong) x);
 	gkrellm_draw_panel_layers(chart->panel);
 	}
@@ -742,8 +745,8 @@ create_panel(GtkWidget *vbox, gint first_create)
 				"leave_notify_event", (GtkSignalFunc) cb_panel_leave, NULL);
 		}
 	gkrellm_update_krell(chart->panel, sound->krell_sensitivity,
-				(gulong) (100.0 * (1 - oscope->vert_sensitivity)));
-	sound->x_sensitivity_raw = (gint) ((1 - oscope->vert_sensitivity)
+				(gulong) (100.0 * (1.0 - oscope->vert_sensitivity)));
+	sound->x_sensitivity_raw = (gint) ((1.0 - oscope->vert_sensitivity)
 				* (gfloat) vu_meter_width) + sound->vu_x0;
 
 	/* To get the negative y_up, must move the krell since the create
@@ -786,7 +789,13 @@ load_config(gchar *arg)
 	if (n != 2)
 		return;
 	if (!strcmp(config, "sensitivity"))
+		{
 		sscanf(item, "%f", &oscope->vert_sensitivity);
+		if (oscope->vert_sensitivity < 0.05)
+			oscope->vert_sensitivity = 0.05;
+		if (oscope->vert_sensitivity > 1.0)
+			oscope->vert_sensitivity = 1.0;
+		}
 	else if (!strcmp(config, "usec_per_div"))
 		sscanf(item, "%d", &oscope->usec_per_div);
 	else if (!strcmp(config, "extra_info"))
@@ -913,6 +922,7 @@ init_plugin(void)
 	oscope = g_new0(Oscope, 1);
 	oscope->usec_per_div = 2000;
 	oscope->vert_sensitivity = 0.5;
+	oscope->vert_max = (gint) (oscope->vert_sensitivity * 32767.0);
 
 	sound = g_new0(SoundMonitor, 1);
 	sound->x_sensitivity_raw = gkrellm_chart_width() / 2;
